@@ -57,21 +57,13 @@ sub _post_data {
     $self->log_info("Posting to %s via %s.", $self->smokedb_url, $self->poster);
     $self->log_debug("Report data: %s", my $json = $self->get_json);
 
-    my $response = $self->ua->post(
-        $self->smokedb_url,
-        { json => $json }
-    );
-    if ( !$response->is_success ) {
-        $self->log_warn("POST failed: %s", $response->status_line);
-        die sprintf(
-            "POST to '%s' failed: %s%s\n",
+    my $response = eval {
+        $self->ua->post(
             $self->smokedb_url,
-            $response->status_line,
-            ($response->content ? sprintf(" (%s)", $response->content) : ""),
+            { json => $json }
         );
-    }
-
-    $self->log_debug("[CoreSmokeDB] %s", $response->content);
+    };
+    $self->log_warn("Error posting: $@") if $@;
 
     return $response->content;
 }
